webbpsf\_ext.bandpasses
=======================

.. automodule:: webbpsf_ext.bandpasses

   
   
   

   
   
   .. rubric:: Functions

   .. autosummary::
      :toctree:
   
      bp_2mass
      bp_gaia
      bp_igood
      bp_wise
      filter_width
      miri_filter
      nircam_com_nd
      nircam_com_th
      nircam_filter
      nircam_grism_res
      nircam_grism_si_ar
      nircam_grism_th
      nircam_grism_wref
      nircam_lyot_th
      niriss_grism_res
      niriss_grism_wref
      qe_nircam
      qe_nircam_flight
      qe_nircam_preflight
      qe_nirspec
   
   

   
   
   

   
   
   



